summaryrefslogtreecommitdiffstats
path: root/src/H5Dint.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Dint.c')
-rw-r--r--src/H5Dint.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5Dint.c b/src/H5Dint.c
index c839df3..ee346f3 100644
--- a/src/H5Dint.c
+++ b/src/H5Dint.c
@@ -464,7 +464,7 @@ done:
/*-------------------------------------------------------------------------
* Function: H5D__get_space_status
*
* Purpose: Returns the status of dataspace allocation.
*
* Return:
* Success: Non-negative
@@ -2181,16 +2181,16 @@ H5D__set_extent(H5D_t *dset, const hsize_t *size, hid_t dxpl_id)
if(H5D__check_filters(dset) < 0)
HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "can't apply filters")
- /* Get the dataspace */
+ /* Get the data space */
space = dset->shared->space;
/* Check if we are shrinking or expanding any of the dimensions */
if((rank = H5S_get_simple_extent_dims(space, curr_dims, NULL)) < 0)
HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get dataset dimensions")
/* Modify the size of the dataspace */
if((changed = H5S_set_extent(space, size)) < 0)
- HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to modify size of dataspace")
+ HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to modify size of data space")
/* Don't bother updating things, unless they've changed */
if(changed) {
@@ -464,7 +464,7 @@ done:
* Function: H5D__get_space_status
*
- * Purpose: Returns the status of dataspace allocation.
+ * Purpose: Returns the status of data space allocation.
*
* Return:
@@ -2181,16 +2181,16 @@ H5D__set_extent(H5D_t *dset, const hsize_t *size, hid_t dxpl_id)
if((rank = H5S_get_simple_extent_dims(space, curr_dims, NULL)) < 0)
HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get dataset dimensions")
- /* Modify the size of the dataspace */
+ /* Modify the size of the data space */
if((changed = H5S_set_extent(space, size)) < 0)